@@ -154,24 +154,13 @@ class GainLayer(ttk.LabelFrame):
 
         if self.parent.target.strip[self.index].levels.is_updated:
             val = max(self.parent.target.strip[self.index].levels.prefader)
-            if _base_values.vban_connected:
-                self.level.set(
-                    (
-                        0
-                        if self.parent.target.strip[self.index].mute
-                        or not self.on.get()
-                        else 72 + val - 12 + self.gain.get()
-                    )
-                )
-            else:
-                self.level.set(
-                    (
-                        0
-                        if self.parent.target.strip[self.index].mute
-                        or not self.on.get()
-                        else 72 + val + self.gain.get()
-                    )
+            self.level.set(
+                (
+                    0
+                    if self.parent.target.strip[self.index].mute or not self.on.get()
+                    else 72 + val - 12 + self.gain.get()
                 )
+            )
 
     def grid_configure(self):
         [
